#-----------------------------------------------------------------------
# File    : ptless.mak
# Contents: commands to build prototype-less clustering programs
# Author  : Christian Borgelt
# History : 2007.02.26 file created
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(MATDIR) /I $(TABLEDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

THISDIR  = ..\..\ptless\src
UTILDIR  = ..\..\util\src
MATDIR   = ..\..\matrix\src
TABLEDIR = ..\..\table\src

HDRS_DM  = $(UTILDIR)\fntypes.h    $(UTILDIR)\scanner.h    \
           $(MATDIR)\matrix.h      $(TABLEDIR)\attset.h    \
           $(TABLEDIR)\table.h
HDRS     = $(HDRS_DM)              $(UTILDIR)\tabread.h    \
           $(UTILDIR)\tabwrite.h   ptlset.h distmat.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(UTILDIR)\random.obj   \
           $(UTILDIR)\params.obj   $(MATDIR)\matrix1.obj   \
           $(TABLEDIR)\attset1.obj $(TABLEDIR)\attset2.obj \
           $(TABLEDIR)\attset3.obj $(TABLEDIR)\table1.obj  \
           $(TABLEDIR)\tab2ro.obj  distmat.obj ptlset.obj
PRGS     = ptli.exe ptlx.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:          $(PRGS)

ptli.exe:     $(OBJS) ptli.obj ptless.mak
	$(LD) $(LDFLAGS) $(OBJS) ptli.obj $(LIBS) /out:$@

ptlx.exe:     $(OBJS) ptlx.obj ptless.mak
	$(LD) $(LDFLAGS) $(OBJS) ptlx.obj $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
ptli.obj:     $(HDRS)               $(UTILDIR)\random.h \
              $(UTILDIR)\error.h    $(UTILDIR)\params.h
ptli.obj:     ptli.c ptless.mak
	$(CC) $(CFLAGS) $(INCS) ptli.c /Fo$@

ptlx.obj:     $(HDRS)               $(UTILDIR)\error.h
ptlx.obj:     ptlx.c ptless.mak
	$(CC) $(CFLAGS) $(INCS) ptlx.c /Fo$@

#-----------------------------------------------------------------------
# Prototype-less Cluster Set Management
#-----------------------------------------------------------------------
distmat.obj:  $(HDRS_DM)
distmat.obj:  $(HDRS) distmat.c ptless.mak
	$(CC) $(CFLAGS) $(INCS) distmat.c /Fo$@

ptlset.obj:   $(HDRS_DM)
ptlset.obj:   $(HDRS) ptlset.c ptless.mak
	$(CC) $(CFLAGS) $(INCS) ptlset.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(UTILDIR)\params.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak params.obj
	cd $(THISDIR)
$(MATDIR)\matrix1.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f ptless.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATDIR)
	$(MAKE) /f matrix.mak localclean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)
